]> git.sur5r.net Git - i3/i3/commitdiff
fix a rendering problem for split cons inside tabbed cons (Thanks julien)
authorMichael Stapelberg <michael@stapelberg.de>
Wed, 2 Feb 2011 16:56:29 +0000 (17:56 +0100)
committerMichael Stapelberg <michael@stapelberg.de>
Wed, 2 Feb 2011 16:56:29 +0000 (17:56 +0100)
This fixes #280.

src/x.c

diff --git a/src/x.c b/src/x.c
index f99dbcfc89674382a2f49177c2fd4beeab686a3d..0e310a5265f48ad9ec3aeebd98f60a9f3b71ab5e 100644 (file)
--- a/src/x.c
+++ b/src/x.c
@@ -233,12 +233,14 @@ void x_window_kill(xcb_window_t window) {
 void x_draw_decoration(Con *con) {
     /* This code needs to run for:
      *  • leaf containers
*  • non-leaf containers which are in a stacking container
      *
      * It does not need to run for:
      *  • floating containers (they don’t have a decoration)
      */
-    if ((!con_is_leaf(con) && con->parent->layout != L_STACKED) ||
+    if ((!con_is_leaf(con) &&
+         con->parent->layout != L_STACKED &&
+         con->parent->layout != L_TABBED) ||
         con->type == CT_FLOATING_CON)
         return;
     DLOG("decoration should be rendered for con %p\n", con);
@@ -233,12 +233,14 @@ void x_window_kill(xcb_window_t window) {
     /* This code needs to run for:
      *  • leaf containers
-     *  • non-leaf containers which are in a stacking container
+     *  • non-leaf containers which are in a stacked/tabbed container
      *
      * It does not need to run for: